@@ -8,6 +8,9 @@ import platform
 import warnings
 import copy
 from datetime import datetime
+import time
+import random
+import json
 
 
 WIN = 'Windows'
@@ -483,4 +486,27 @@ def benchmark(func):
         elapsed = (end - start).microseconds
         print(f'Elapsed {elapsed} ms during running {func.__name__}')
         return result
-    return new_func
\ No newline at end of file
+    return new_func
+
+
+def random_sleep(min=0, max=3):
+    time.sleep(random.uniform(min, max))
+
+
+def load_json(file_path):
+    data = None
+    if os.path.exists(file_path):
+        with open(file_path, 'r', encoding='utf8') as fp:
+            data = json.load(fp)
+    return data
+
+
+def dump_json(file_path, data, indent=2, ensure_ascii=False, lock=False):
+    dir_path = os.path.dirname(file_path)
+    if not os.path.exists(dir_path):
+        os.makedirs(dir_path)
+    with open(file_path, 'w', encoding='utf8') as fp:
+        if lock and is_win():
+            import fcntl
+            fcntl.flock(fp, fcntl.LOCK_EX)
+        json.dump(data, fp, indent=indent, ensure_ascii=ensure_ascii)
\ No newline at end of file
